;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tray" "20251016.1406"
  "Various transient menus."
  '((emacs     "27.1")
    (compat    "30.1")
    (transient "0.11"))
  :url "https://github.com/tarsius/tray"
  :commit "50b43a362cf26ae8877a247d534f2e417193bee9"
  :revdesc "50b43a362cf2"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.tray@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.tray@jonas.bernoulli.dev")))
